@@ -21,9 +21,9 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None):
 
     if credentials is None:
 
-        #post_url = "https://api.askdata.com/smartnotebook/readGsheet"
+        post_url = "https://api.askdata.com/smartnotebook/readGsheet"
         
-        post_url = 'https://smartnotebook.askdata.com/readGsheet'
+        #post_url = 'https://smartnotebook.askdata.com/readGsheet'
         
         body = {
             "spreadsheetId": spreadsheetId,
